package web

import (
	"bytes"
	"compress/gzip"
	"fmt"
	"io"
	"strings"
	"os"
	"time"
	"io/ioutil"
	"path"
	"path/filepath"
)

func bindata_read(data []byte, name string) ([]byte, error) {
	gz, err := gzip.NewReader(bytes.NewBuffer(data))
	if err != nil {
		return nil, fmt.Errorf("Read %q: %v", name, err)
	}

	var buf bytes.Buffer
	_, err = io.Copy(&buf, gz)
	gz.Close()

	if err != nil {
		return nil, fmt.Errorf("Read %q: %v", name, err)
	}

	return buf.Bytes(), nil
}

type asset struct {
	bytes []byte
	info  os.FileInfo
}

type bindata_file_info struct {
	name string
	size int64
	mode os.FileMode
	modTime time.Time
}

func (fi bindata_file_info) Name() string {
	return fi.name
}
func (fi bindata_file_info) Size() int64 {
	return fi.size
}
func (fi bindata_file_info) Mode() os.FileMode {
	return fi.mode
}
func (fi bindata_file_info) ModTime() time.Time {
	return fi.modTime
}
func (fi bindata_file_info) IsDir() bool {
	return false
}
func (fi bindata_file_info) Sys() interface{} {
	return nil
}

var _static_css_sm_css = []byte("\x1f\x8b\x08\x00\x00\x09\x6e\x88\x00\xff\x7c\x90\x51\xce\xd3\x30\x10\x84\xdf\x73\x0a\x4b\x7d\xe8\x5f\x41\xda\x90\x56\x28\xb8\x42\x54\x42\x1c\xc4\xb5\x9d\x74\x85\xed\x8d\xec\x4d\x69\x41\xbd\x3b\x4e\xe3\x84\x34\x20\xfc\xb8\x33\xeb\xf9\x76\x4e\x60\x5b\xf4\xc4\x3a\x6f\xde\x2e\x44\x2d\xdf\xed\x6a\x74\x14\xb6\x0d\x62\x63\xb4\x68\x21\x6c\x25\xda\x9d\x0c\xe1\x4b\x2d\x2c\x98\xfb\xe7\x6f\x37\x7c\x57\xf2\x4f\x45\xb1\x39\x66\xd9\x19\xd5\x9d\xfd\xca\x58\x7c\x67\x21\xbf\x37\x1e\x3b\xa7\x72\x89\x06\x3d\x67\xab\xb2\x2c\x8f\x4f\x6d\x1c\xd4\x75\x3d\x0c\x48\xdf\x28\x17\x06\x1a\xc7\x99\xd4\x8e\xb4\x1f\xe6\x7d\x78\x3e\x04\x71\xb6\xfe\x8a\x9d\x07\xed\xd7\x83\xd6\x0a\xa5\xc0\x35\x9c\x95\x45\x7b\x3b\x66\x8f\x2c\x13\x29\x7a\xfa\xbe\xaa\x66\xdf\x2b\x2d\xd1\x0b\x02\x8c\x19\x0e\x9d\x7e\xae\xf0\x2b\x04\x20\xad\x16\x9b\xb2\xdf\x8c\xf2\x4a\x46\x80\xc8\x93\xe4\xab\xf6\x04\x52\x98\x11\xd5\x82\x52\x46\x0f\x19\x56\xf8\x06\x5c\x6e\x74\x4d\x9c\x89\x8e\xf0\x65\xec\xa1\xb9\xfc\x6b\x4e\xd8\x8e\x07\x4c\xf7\x06\xf8\xa9\x67\x57\xad\x08\xc8\xe8\x44\xf0\x5a\x48\xec\x9e\x95\xeb\xf7\x2c\x08\x17\xf2\xa0\x3d\xa4\x3a\xff\xc7\x39\x8b\x38\x54\x63\x6e\xea\x32\x3f\x23\x11\xda\xa8\x4c\xe1\xe0\x6a\x4c\xd9\xa3\x69\xc6\x1c\x1d\x27\xab\x15\x08\xf6\x66\xe3\x35\x3f\x40\xd1\xa5\xdf\x8e\xe2\x26\x6d\x2d\x2a\xec\x5f\xb2\xed\xab\xe9\xee\x05\xd8\x87\x09\x2c\x06\x3c\x3f\x99\x77\xb0\x30\x7f\x3c\x2c\xcd\x33\xe6\xbf\xb8\xf7\xc5\x1f\xf7\x23\xfb\x1d\x00\x00\xff\xff\xd8\x97\x08\xca\xf0\x02\x00\x00")

func static_css_sm_css_bytes() ([]byte, error) {
	return bindata_read(
		_static_css_sm_css,
		"static/css/sm.css",
	)
}

func static_css_sm_css() (*asset, error) {
	bytes, err := static_css_sm_css_bytes()
	if err != nil {
		return nil, err
	}

	info := bindata_file_info{name: "static/css/sm.css", size: 752, mode: os.FileMode(420), modTime: time.Unix(1423548433, 0)}
	a := &asset{bytes: bytes, info:  info}
	return a, nil
}

var _static_favicon_ico = []byte("\x1f\x8b\x08\x00\x00\x09\x6e\x88\x00\xff\x62\x60\x60\x04\x42\x01\x01\x10\xad\xc0\x90\xc1\xc2\xc0\x20\xc6\xc0\xc0\xa0\x01\xc4\x40\x21\xa0\x08\x44\x1c\x17\xf8\xff\xff\x3f\x43\x88\x9f\xc5\xff\x7f\x0f\xcb\x48\xc2\x20\x3d\x20\xbd\xa3\xfa\x69\xa7\xff\xfc\xee\xca\xff\x87\x36\x55\x81\xd9\xff\xef\x97\xff\xff\x7f\x17\x82\x09\xe9\xff\xff\xa0\xf2\x7f\x49\xcf\xe1\xff\xbf\xff\xfc\x07\x63\x10\x1b\x2c\x4e\x40\x3f\xc8\x0e\x98\x19\xcb\x16\x77\x82\xf5\x81\x70\xdf\xcc\x65\x10\xf9\x87\xa5\x40\x35\x15\x38\xf5\x7f\xbe\x5a\xf2\x1f\x06\x4e\x6c\x2e\xfa\x2f\xaf\xa0\x0c\xc6\x20\x36\x0c\x80\xd4\x20\xeb\xbf\x7e\xf3\xee\x7f\x98\xfe\xe7\x0f\x2f\xfd\xff\xfd\xef\xff\x7f\x41\x61\xf1\xff\x7a\x3a\xea\x70\xb7\x80\xc5\xff\xa0\x8a\x83\xf4\xc0\xf4\x56\x64\x98\xfc\x3f\xb1\xdc\x0f\xac\x0e\x04\xb0\xe9\x47\x16\x07\xa9\x2d\x4d\x35\x07\xeb\x05\x61\x10\x7f\xd5\x24\x0f\xb0\x3b\xbf\x7e\xfb\xfd\xff\xfb\x2f\x88\xfb\x61\xfa\x91\xdd\x0f\x62\x83\xd5\x02\xf5\x20\xbb\xa1\xba\xd8\x0f\x2e\x0e\xc2\xe8\x71\x79\xe6\xe0\xb4\xff\xa7\xf6\xf7\xff\x5f\x3a\x29\x04\xac\x16\xa6\x17\x16\x86\x0f\x1f\x3d\xfd\xbf\x60\x4e\x0f\x58\x0e\x84\xc3\xfd\x0c\xff\x3b\x5a\xa9\xfe\xf7\x73\x55\xff\x9f\x1a\xae\x0b\x17\x07\xa9\x01\xa9\x85\xe9\xc3\x85\x5f\xbd\xfe\xf8\xff\xce\xfd\xc7\x60\x3b\x40\x6c\x5c\xea\x28\x05\x80\x00\x00\x00\xff\xff\x9f\x48\x88\x13\x7e\x04\x00\x00")

func static_favicon_ico_bytes() ([]byte, error) {
	return bindata_read(
		_static_favicon_ico,
		"static/favicon.ico",
	)
}

func static_favicon_ico() (*asset, error) {
	bytes, err := static_favicon_ico_bytes()
	if err != nil {
		return nil, err
	}

	info := bindata_file_info{name: "static/favicon.ico", size: 1150, mode: os.FileMode(420), modTime: time.Unix(1423544989, 0)}
	a := &asset{bytes: bytes, info:  info}
	return a, nil
}

var _static_img_smcquay_png = []byte("\x1f\x8b\x08\x00\x00\x09\x6e\x88\x00\xff\x00\x87\x13\x78\xec\x89\x50\x4e\x47\x0d\x0a\x1a\x0a\x00\x00\x00\x0d\x49\x48\x44\x52\x00\x00\x00\x50\x00\x00\x00\x50\x08\x06\x00\x00\x00\x8e\x11\xf2\xad\x00\x00\x00\x06\x62\x4b\x47\x44\x00\xfa\x00\xfa\x00\xfa\x1e\xfc\x1e\x87\x00\x00\x00\x09\x70\x48\x59\x73\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07\x74\x49\x4d\x45\x07\xdf\x02\x0a\x05\x0d\x2a\x52\x1f\xc2\x2e\x00\x00\x13\x14\x49\x44\x41\x54\x78\xda\xed\x9b\xeb\x93\x55\xd5\x99\xc6\x7f\x6b\xed\xfb\x39\xdd\xf4\x8d\x3b\x2d\x88\xc0\xa8\x88\x77\x0c\x06\x34\xc6\xfb\x04\x31\x26\x15\x75\xca\x64\x9c\xd4\x54\xa5\x92\xf9\x33\x92\xff\x60\x6a\xbe\x65\x32\x35\x49\x39\x26\x93\x49\x70\x32\x63\x89\x49\x50\x93\xa0\x21\x21\x8a\xa8\x20\x46\x89\x42\x83\x34\xd7\xbe\xd1\x87\x73\xd9\x97\xb5\xde\xf9\xb0\xf6\x39\xdd\x20\x12\x71\x34\x6d\xa4\xdf\xaa\xee\xd3\xbd\xcf\xee\x7d\xd6\x7e\xf6\x7b\x79\xde\x67\xbd\x0d\xb3\x36\x6b\xb3\x36\x6b\xb3\x36\x6b\xb3\x36\x6b\xb3\x36\x6b\xb3\x36\x6b\xb3\x36\x6b\xb3\x36\x6b\x17\x60\xea\x93\xb4\x18\xcf\xf3\x48\x92\x84\x38\x8e\x7f\x12\x86\xe1\x43\x41\x10\x00\x90\x65\x19\x79\x9e\xff\xb4\xd5\x6a\x3d\xdc\x6c\x36\x31\xc6\xcc\x02\xb8\x7c\xf9\x72\x59\xbd\xfa\x4a\x7a\xaa\x31\xa1\x27\x28\x9b\xa3\xb1\xe4\xad\x06\xcd\x46\x9d\x22\xcf\x28\x8a\x1c\x00\x3f\x08\x08\xfc\x90\xa4\x5a\x25\x88\x2a\x88\xf2\xb0\xca\xa7\x55\x08\x93\x8d\x8c\x3d\x7b\x5e\xe7\xd0\xa1\x43\xea\x53\x0f\xe0\xfc\xf9\xf3\xc7\xbe\x70\xcf\x5d\x7d\x5d\x21\x8c\x1e\x1d\xe2\xcd\xd7\x5f\x25\xcf\x52\x50\x67\x2e\x44\x9d\xb5\x42\x25\xef\xbf\xd2\x28\x8e\xb9\x72\xcd\xf5\xf4\x2e\x5c\xc6\xa9\xa6\xe5\xe9\x5f\x3e\xfb\xf2\xc9\x93\x27\xd7\x7e\xaa\x00\x8c\xa2\x88\xaf\x3d\xf2\x77\x12\xda\x3a\x47\x0e\xee\x67\xd1\xe2\x25\x88\x18\x14\x20\xc0\xee\x97\x77\x70\xba\x36\x39\xed\x2f\x04\x55\xa2\xaa\xdc\xaf\xc8\x59\x20\x77\x77\xf7\xb0\xe6\x86\xcf\x00\x0a\xad\x15\x5a\x6b\x8e\x1f\x1d\x66\xc9\xb2\x15\x9c\xb6\x09\xff\xf1\xa3\xff\x52\x59\x96\xfd\xf5\x03\xb8\x74\xe9\x52\xf9\xea\x43\x5f\xe2\xd7\x4f\x3f\xc1\x35\xd7\xdd\xc0\xbb\x43\xef\x70\xf0\x9d\xb7\xd0\x0a\xe2\x38\x24\xf0\x7d\xae\xb9\xf1\xb3\xfc\xe9\xad\x37\x38\x79\xec\x88\x5b\xd4\xb4\x55\xb9\x9f\xdb\x50\xbb\x37\xe6\x2d\x58\xcc\xe2\x4b\x57\xf1\xea\x8b\xbf\x25\x0e\x03\x7c\xdf\x03\x11\x96\x2c\xbb\x8c\x45\x83\xcb\x78\x63\xf7\x2e\x36\xdc\xf3\x15\x7e\xf0\xe3\x9f\x7d\xec\xa1\xfd\xb1\x5e\xfc\x8a\x2b\xae\x90\x7b\x6e\xdf\xc0\xf6\x5f\xfd\x9c\xeb\xae\x5f\xcb\xef\xb6\x3d\x43\x91\x67\x68\xe5\x80\xa9\xc4\x11\x41\xe0\xa3\x15\x5c\xb3\x76\x3d\x2f\xfd\xee\x79\xb2\x2c\x9d\x5a\xd4\x34\xaf\x6b\xc3\x97\x54\xaa\xac\xb8\xfa\x66\x5e\xde\xfe\x1c\xd5\x24\x22\xf0\xfd\xce\x79\x4a\x81\xef\xfb\xdc\x70\xf3\xe7\xd8\xf3\xca\x4b\xac\xfb\xfc\x17\xf8\x9f\x5f\xfe\x96\x3f\xbe\xf9\xa6\xfa\xab\x03\xf0\xaa\xab\xae\x92\x5b\x6e\x5e\xcb\x9b\x7b\x5e\x66\xde\x40\x3f\xbb\x5e\xdc\x8e\x42\x10\x71\x60\x00\xf8\x5a\x51\x89\x43\xe2\x28\xc0\xf7\x34\xab\xae\xba\x9e\x9d\xbf\x7f\x1e\xd5\x81\x6b\x2a\x94\x01\x82\x20\xe0\xaa\xb5\x9f\xe3\xf9\x6d\xbf\xa1\x2b\x82\x24\x8a\x3a\xd7\x6a\x03\xa8\xb5\x42\x03\xab\xaf\xbb\x89\xd1\x91\x13\xfc\xcd\x9a\x1b\xf9\xdf\x67\x77\xf0\xe6\xc7\x04\xa2\xf7\x71\x5c\x74\xdd\xba\x75\x72\xe3\x35\x57\x32\x72\xec\x08\x45\x7a\x9a\xbd\xbb\x77\x01\x60\x04\x0a\x0b\xb9\x11\x32\xe3\x5e\x0b\x63\x08\x3c\x85\xa7\x35\x71\x1c\x63\x8c\xa5\xd9\x6c\x4c\x81\x52\xfe\x14\x84\x01\xf3\x17\x2e\xe1\xd0\xc9\x3a\x79\x6d\x84\x4a\x1c\x01\x90\x66\x39\xad\x34\x23\xcd\x72\x8c\xb5\x28\xa5\x50\x5a\x33\x72\xfc\x08\x7d\xfd\xf3\x30\x45\xc6\x0d\x57\x5f\x49\xae\xa2\x6f\x0f\x0f\x0f\x7f\xe7\xa3\xbe\x57\xff\xa3\xbe\xe0\x5d\x77\xde\x29\x57\xad\x5a\x4a\x6d\x72\x82\x03\x6f\xbd\xc6\xa9\x89\x71\x44\xc0\xd8\x36\x80\x42\x56\x40\x5a\x08\x46\x20\xf1\x05\x48\x19\xe8\xf1\x38\x7c\x70\x3f\x2b\xae\xb8\x9a\x89\xb1\x91\xf7\xc4\x88\xe7\xf9\xc4\x7d\x8b\x39\xfc\xfb\xed\x0c\x74\x05\x80\xa2\xd9\x6c\x51\x58\xe7\xd5\x56\x84\x3c\x2d\x48\x33\x43\x1c\xf9\x24\x51\xc0\xbb\x43\x6f\xd3\xd5\x3d\x87\x39\x73\x7a\xb9\xeb\xe6\x35\x74\x77\x77\xc9\x73\xcf\xfd\x4a\x7d\x62\x3d\xf0\xce\x3b\xef\x94\x4d\xf7\xde\xce\x1b\xaf\xed\x64\xc7\xb6\x67\x69\xb5\x9a\x14\x96\xce\x97\xb5\x0e\xb4\xc2\x40\xb3\x70\xc7\x52\x03\xb9\x15\x22\x2d\xc4\x51\x00\x62\xf1\x83\x90\x66\xb3\x81\xe7\x7b\x78\x9e\x8f\xef\xfb\xf4\x0c\x2c\xe4\xed\x77\x47\x08\x4c\x9d\x24\x0a\xc9\xb2\x0c\x63\x2d\x88\x42\xa4\x0d\x62\xf9\x90\x0a\x4b\x5e\x14\x28\xa5\x30\x45\xce\x91\x43\x07\xa8\x56\xab\xdc\x7d\xf7\x5d\xd4\x53\xfb\xed\xa1\xa1\xa1\xef\x7c\xe2\x3c\x70\xfd\xfa\xf5\xb2\xf1\xce\x5b\x79\xec\xbb\xff\xcc\xc4\xf8\x18\xa6\x0c\xd5\xc2\x96\x05\x40\x81\xa7\x41\x03\x9e\x02\xa5\x14\xf5\x5c\x30\x16\xea\x19\x9c\x3c\x5d\x10\x47\x39\xe3\xa3\x27\x59\x34\x78\x29\xcd\xfa\x69\xb4\xd6\x18\x11\x0e\x8f\x65\xa4\x5d\x11\x8d\xf1\x21\x7a\xab\xc1\x14\x78\x28\x97\xf7\x94\x42\x09\x28\x11\xac\x75\x40\xb6\x72\x21\x2b\x52\xa2\xa0\xa0\x9a\x84\xec\x79\xe5\x25\x86\xde\xd9\xc7\xc3\x8f\xfe\x13\xad\x66\x53\x7e\xbf\x63\x87\xfa\x44\x14\x91\x15\x2b\x56\xc8\xa6\xbf\xbd\x8b\x03\x6f\xbe\xc2\x9e\x57\x76\x4e\xe5\xb8\xd2\xc3\xb4\x82\xd0\x83\xc8\x57\xf8\x9e\xfb\xbd\xed\x2d\x99\x11\x26\x9a\x42\x23\x77\x0b\x59\x34\x47\xb3\x78\xa0\x42\x14\x06\xcc\x5b\xb0\x98\x63\x47\xde\xe5\x4f\xc7\x9a\xcc\x5d\x78\x09\xcd\xf1\x61\x22\x55\x10\xf8\x1a\x6b\x0c\x28\xc7\xfd\xc2\x20\xc0\xf3\xb4\xab\xd4\x56\x30\xd6\x92\x15\x86\x34\x2b\xc8\x8d\x7b\x78\x9e\x86\x6a\xe4\x53\x4d\x42\x7c\x4f\x73\xf9\x55\xd7\x31\xb0\x6c\x35\x3f\x7b\x6a\x2b\xfb\xf7\xef\x57\x33\x02\xa0\x52\x8a\xbf\xff\xda\x57\xc5\x34\xc6\xf8\xed\xaf\xb6\x52\x58\x4b\x6e\x70\xf9\xcd\xb8\x90\x8a\x7c\x45\x35\x84\xd8\x57\x04\x1e\x68\xed\xf8\x88\x15\xe7\x91\x02\xe4\x06\x46\xeb\x96\xc9\xd4\x01\xbd\xb4\xcf\x67\x60\x4e\x82\xef\xfb\x24\x5d\x73\x18\x6f\x18\xea\x13\x23\x98\xc2\xd1\x9f\xf6\x67\xfb\xbe\x47\x1c\x46\x28\x3d\xc5\x12\x11\xf7\x19\x0a\x45\x61\x2c\xcd\x34\xe3\x74\xab\xa0\x95\x0b\x4a\xb9\x75\x74\x25\x01\x95\x38\xc4\xd7\x9a\x1b\x37\xdc\xce\xa4\xad\xf0\xd8\xe3\xff\xa9\x44\xe4\x2f\x0b\xe0\x83\x0f\x3e\x28\xbb\x5e\xde\xc9\xe1\x43\x43\x9d\x1b\x2b\xca\xf0\xf1\x35\x54\x43\x45\x35\x74\xc0\x15\x16\x32\xe3\xc8\x89\xa7\x14\x85\x38\x2f\x8c\x3d\x4b\x25\x70\xef\x8f\x94\x20\xf6\xc6\x8a\x45\xbd\x01\xdd\x95\x08\xad\x14\xcd\x56\x4a\x9a\x15\xd8\x69\x8b\xf5\x3d\x4d\x1c\x47\x28\xa5\xc8\x8b\x82\x66\x26\x14\xc6\x62\x51\x34\x73\x21\x0e\x34\x7d\x15\x8f\x38\xf0\x28\x8c\xa1\xd6\xc8\x38\xd5\x74\x1e\x19\xfb\x50\x09\x35\x95\xc8\x27\xf0\x3d\xe6\x2f\x5c\xc2\x9c\x65\xd7\xf2\xe3\x9f\x6c\x56\x1f\x6b\x0e\x4c\x92\x84\xee\xee\xee\xb1\x5a\xad\xd6\x9f\xa6\x29\x5a\x6b\xf6\x1f\x18\x3a\xa3\x63\x08\x3d\xa8\x78\xee\x49\x7b\x1a\x6a\xa9\xd0\x2a\x14\x49\xa8\xe8\x8b\x21\x09\xc0\x53\x82\xef\xfb\x18\x15\x70\x78\x3c\xa3\x91\xe5\xcc\xad\x2a\xfa\x2b\x1a\xc1\x92\x1a\x61\xb2\x91\x63\xad\x90\x44\x01\x52\xb2\x42\xc4\xb9\xad\x52\x10\x46\xa1\xa3\x30\x69\x46\x9a\x1b\xb4\x12\xaa\x3e\x84\x61\x80\xd6\x1e\xa9\x51\x9c\xa8\x19\xd2\x3c\x65\x7e\x77\x40\x4f\x57\x4c\x14\xe4\x9c\x6a\x64\x64\x85\x90\x16\x02\xe4\xf8\x79\xc1\xc1\xa1\xfd\xdc\xb1\xe6\x46\x74\x49\xa3\xba\xba\xba\xc6\x6a\xb5\x5a\x7f\xb3\xd9\xfc\x68\x3c\x70\x70\x70\x50\x1e\xfc\xd2\x7d\x8c\x1e\x3d\xc8\xe8\xc8\x08\x3d\xbd\x7d\xf4\xcf\x9d\xc7\x9f\xde\x1d\x61\xeb\xd6\xad\x9d\x8b\xcc\x89\x1d\x70\x4a\x39\x2f\x1c\x6f\x82\xa0\x99\x13\x59\xba\x23\x45\xe4\x2b\x3c\x05\x9e\xa7\x49\xa2\x10\xad\x15\x4a\x69\xde\x3a\xd6\xa0\xea\x1b\x2a\xa1\xa6\x99\x09\xcd\x5c\xf0\xb4\x0b\xff\xd0\x73\x05\xa2\x5d\x84\x14\x10\x04\x3e\x61\x18\x22\xd6\xd2\x68\xb6\x3a\x0f\x2f\x89\x42\xc2\xc0\x47\x29\x85\x88\x45\xc4\x71\xcd\xfd\x27\x53\x22\x4f\x58\x3a\x37\xc6\x5a\xa1\xd6\x48\xb1\x56\xd0\x5a\xe1\x97\x1d\xd1\x2d\x77\xdc\xcb\x9c\xbe\x79\x34\x4e\x8d\x50\x3b\x35\xc1\xc0\xbc\x05\x84\x3d\x0b\xf8\xd1\xe6\x27\x19\x1e\x1e\x56\x1f\xda\x03\xe7\xcf\x9f\x3f\xf6\xd5\xaf\xdc\xcf\xe6\xc7\xbf\xc7\xc8\xe9\x82\xc9\xd4\x1d\xaf\x26\x11\x9f\xb9\x79\x7d\xe7\x3c\xad\x20\xf2\x5c\x53\x2f\x02\x89\x0f\xad\xc8\x67\xb2\x91\x31\xd9\x82\xd0\x53\x78\x4a\x10\x0d\x82\x0b\x35\x5d\x66\xae\x4b\xe7\xc6\xec\x3f\x5e\xa7\xb7\xea\x63\x6c\x8e\xa0\xb0\x65\x88\x17\x16\x3c\x2d\x68\xa5\x3a\x1e\x68\xad\x25\x2f\x45\x82\xb4\x10\x72\x03\x73\x2a\x8e\xea\xe0\x7a\x1d\x94\xd2\x80\x05\x93\xb2\x74\x8e\x70\xa8\xe6\x31\x56\x4b\x99\xd7\x93\xd0\x95\x84\x34\x5b\xd9\xb4\xe6\x50\xc8\xb3\x94\xe7\x9e\xfa\x29\xad\x56\x8a\x00\xbe\xa7\xe8\xaa\x56\xf8\xd6\x3f\xfc\x23\xff\xf2\xbd\x1f\xfe\x64\x64\x64\xe4\xe1\xf7\xc3\x48\x9f\x0f\xc0\x2f\x3f\x70\x7f\xdf\x7f\xff\xe8\xdf\x10\xb1\x14\x76\xea\x78\xbd\x99\x12\x86\xe1\x34\xed\xc4\xf1\xaf\xbc\x10\x44\x84\xae\x4a\x48\x23\x75\xa2\xa7\x15\x77\x5b\x6d\x50\xac\x08\x79\x5e\x38\xce\x66\x2c\x91\xaf\x09\x7c\x0f\xa5\x34\x9e\x56\xf8\xda\x55\x4d\xca\x22\x23\x02\x53\x09\x5e\x30\xc6\x60\xac\xa5\x99\x5b\x26\x53\x61\xa2\x25\xf8\x5a\xbb\x73\x71\x7d\xe2\x14\x88\x0a\xad\x84\xbe\x78\x2a\x83\x06\xbe\x8f\xa7\x4b\x91\x42\xb9\x62\xe7\x07\x11\xe3\xb5\x16\xe3\x4d\xcb\x68\xdd\x32\x56\x37\x4c\x9e\x6e\xf2\x8b\xcd\x8f\xf1\xc8\x43\x5f\x7e\xe8\x43\x79\x60\x1c\xc7\xd4\x27\x46\x50\x62\xf0\xb5\x03\x62\xba\xb5\xd5\xe2\x36\x48\xcd\x5c\x50\x40\x1c\x28\x97\xe3\x6c\xda\x79\x2f\x37\xae\xb0\x68\x05\x4a\x5c\xe2\x0f\x82\x00\xb1\xd6\xe5\x9e\xc0\xc3\x8a\xe0\x69\x85\xa7\x05\xec\x74\xed\x85\xd2\xb3\x4a\x59\x0b\xf0\x50\x9c\x4e\x0d\xe3\x0d\x21\x0e\xa0\x30\x86\x50\x02\x2c\x94\xde\x3a\xf5\xc7\x82\x22\xd4\x82\xf2\x3c\xac\x15\x8a\xa2\x28\xaf\xa8\x4a\xd0\xc1\x2a\x9f\x46\x2e\x08\x9a\x46\x21\x34\x1a\x96\xd4\x14\x24\x71\x86\x97\x4d\x10\x45\x11\x69\x9a\x5e\x18\x80\xab\x56\xad\x92\x37\xf6\xee\x26\x0a\x02\x72\x63\x48\xa7\xbb\x20\x90\xe7\x39\x41\x10\x90\xe7\x4e\x35\x6e\xe6\x25\x98\x08\xd6\x18\xb4\x56\x18\xe3\x50\x6f\x15\x82\xef\x39\xfa\xa1\x94\x23\xcf\x45\x51\x60\x6d\x81\xb5\xd6\x85\x1b\x1e\x22\xd2\x11\x05\x90\x33\x95\x98\x36\x2a\x56\x04\x63\xa5\x03\xaa\xa3\x4e\x96\xb0\x30\xf8\xbe\xf3\x44\x14\x58\xe3\x2a\x33\x52\x56\xed\xc8\x27\xcf\x73\xf2\x22\x47\x44\x75\x44\xc6\x20\x08\x89\x3c\xcb\x65\x0b\xba\x3a\x29\xe8\xed\x13\x4d\xc6\xeb\x39\x79\x61\xd8\xbf\xef\x0d\x56\xae\x5c\x29\x7b\xf7\xee\x55\x17\x14\xc2\x71\x1c\x33\x3e\x3e\x81\xe7\x69\x7c\xad\x18\xa8\xa8\x0e\x5d\x01\xf8\xc3\x1f\xfe\xc0\x86\x0d\x1b\xce\x08\x63\x29\x81\x3c\x31\x99\x62\xcd\x14\xe0\xf5\x0c\x1a\x99\x74\x3a\x13\x6b\x85\x46\x2b\x25\xcb\xad\xa3\x28\xc6\x60\x8a\xbc\x4c\x73\x0a\xad\x54\x47\xf2\x52\x6a\x4a\x50\x68\x13\xf0\xb4\x30\x04\xbe\xee\x50\xa7\xb1\x86\xa5\xd1\x6a\xd1\x6c\xa5\x4e\x58\x48\x33\x1a\xcd\x26\xc6\x0a\x16\x88\x43\x27\x99\xe5\x45\xd1\x71\xcd\x76\x75\xbf\x61\xdd\x06\xf6\xed\x7d\xb5\x2c\x3e\x6e\xbd\x97\xf4\x47\x65\xff\x2e\x9c\x1a\x1f\x23\x49\x92\x0b\x0f\xe1\x89\x89\x09\x06\xe6\x2f\x24\x1b\x3d\x80\xd2\x9a\x46\x2e\x67\x84\xf1\xc4\xc4\x04\xbd\xbd\xbd\xe5\x07\x9f\x19\xdf\xc7\x6b\x67\x7a\xab\x00\xb5\xd4\x75\x1e\x71\xe0\xc2\x59\x04\x7a\x13\xf0\xb4\x22\x09\xa6\xfc\x4c\x95\x79\x4b\xa6\xe8\x71\x29\xeb\x4b\x5b\xdc\x22\x37\x30\x2d\x83\x30\xde\x74\x3d\x76\x5f\x6c\xf0\x3d\xe3\x84\x0b\xeb\x68\x53\xe0\x7b\x78\x9e\x47\xb3\xd5\xea\xac\x53\x28\xfb\x67\x34\xfd\x03\xfd\xbc\xb5\xfb\x94\x2b\x5a\x45\x41\x51\x14\x88\x08\xa1\xaf\xf1\x3d\x4d\xff\xbc\x05\x1c\x39\x7c\x8a\x0b\x2e\x22\x07\x0f\x1e\x54\x97\xad\xba\x92\xa2\xb0\x34\x72\x45\x23\x7f\xef\x39\x2f\xbe\xf8\x22\x9f\xfd\xec\x67\x3f\x10\x5f\x12\xa0\x55\xc0\x44\x53\x18\xa9\x3b\x2e\x56\x58\x07\xa4\x4b\xea\x1a\xdf\xf7\x4b\x7a\xe3\x40\x9c\xf2\x40\x29\x7b\x5e\x41\x6b\xf7\x00\x1a\x69\x41\x77\x34\xb5\xfc\xc9\x96\x70\x70\xc2\x72\x60\xcc\x72\xb4\x66\x11\x04\x51\x9a\x30\x0c\x68\x34\x5b\x18\x63\xcb\x82\xe4\x8a\x92\x15\xb8\xfe\x33\xeb\xd9\xf7\xfa\x2b\x88\x40\xab\xd5\xa2\x95\xa6\x18\x63\xb0\x22\x44\xbe\x22\xf0\x34\x4b\x96\xad\x64\x68\x68\x48\x5d\x30\x80\x59\x96\x11\x57\xba\x18\xa9\x1b\x0e\x8d\x65\x28\xf5\xde\x6b\x1c\x39\x72\x84\xae\xae\x2e\xfa\xfb\xfb\x2f\x6c\x8f\xa4\xec\x8d\xb3\x42\x68\xe5\x4e\x00\xf0\x3d\x8f\x38\x8a\xa8\x56\x62\x92\x28\xc4\xf3\x74\x19\xca\xee\x4b\x95\x5f\xbe\xd6\x84\xbe\x22\xf1\x41\x61\xdf\x73\x6d\x2b\x90\x04\x8a\x38\x0c\x88\x03\x8f\x7a\x33\xa5\xb0\xd2\x51\x17\x2d\x0a\x2b\x8a\xee\xde\x01\x06\xfa\x7a\x19\x3d\x79\x9c\x3c\xcf\x31\xc6\x96\xfe\xad\xc8\xc5\x63\xa0\xcb\x03\x05\xb9\x57\xed\xe4\xf9\x0b\xa6\x31\xdb\xb6\x6d\x63\xdd\xe7\x37\x52\x18\x7b\x4e\x00\x01\x9e\x79\xe6\x19\xee\xb8\xe3\x8e\x33\xaa\xf2\xf9\x2c\xf6\xa7\x3c\x26\x37\x6d\xef\x9b\x46\x96\x95\x22\x08\x7c\x2a\x49\x8c\xef\x7b\x9d\xfd\x11\xa5\x20\x0a\x03\x2a\x49\x4c\x57\x25\xa1\xa7\x1a\xb1\x70\x8e\x4f\x5f\xa2\x88\x7d\x88\x7c\x58\x38\xc7\xe3\xd2\x81\x80\xb9\x5d\x3e\xd6\x1a\x4e\xb7\xf2\x32\xed\xb8\x5c\x68\xca\x02\x64\x95\xcf\xe7\x6e\xbf\x9b\x5d\x3b\xb6\x81\x94\x95\xb9\x54\x6f\xc3\x30\x40\x29\x4d\x7f\x35\x60\xdd\xe7\xee\xe1\xe7\xcf\xfc\xfa\xbc\xf7\x73\x5e\x00\x0f\x1e\x3c\xa8\xa2\x28\xe2\x8a\x2b\xae\xc0\xda\x73\x83\x28\x22\x3c\xf5\xd4\x53\xdc\x7f\xff\xfd\x1f\x08\xc4\x56\xe1\xc0\xe8\x4b\x5c\x8b\xd7\x2e\x4c\xae\x1a\x4f\xa9\xd0\x4a\x29\xe2\x28\x24\x49\x92\x8e\xda\xe2\xfb\xae\xd3\xd0\xda\x81\xdc\x5d\x8d\x19\xec\x0b\xb9\xa4\x57\xb3\xb0\x4b\xbb\xee\xa4\x55\xd0\x48\x0b\x8c\x15\x57\x88\x00\x6b\xa1\x30\xee\x81\x15\x04\xdc\xb3\xf1\x01\x76\x6d\x7f\x06\x44\xa6\x3a\x1c\xdf\xa3\x92\xc4\x88\x28\xba\x22\x8f\xc1\x65\x2b\x19\x69\xe8\x3f\xbb\x29\xf5\x81\x1a\xe8\xaf\x7f\xfd\xeb\xb2\x6b\xd7\x2e\xf6\xec\xd9\xc3\xf9\xaa\xf6\xa6\x4d\x9b\xd8\xb2\x65\x0b\xe7\xeb\x23\x7d\x4d\xd9\xda\x41\xd0\x21\xce\xae\x77\xae\x56\x13\xbc\x69\x0f\xc9\x0a\x34\x5b\x2e\x7f\x29\x05\x49\x1c\x77\xc0\x54\x65\x77\x22\xb8\xfc\x55\x14\x06\xdb\x21\xde\x53\x24\xdc\x88\x03\x30\xb7\x82\x0a\x2a\xdc\xbf\x69\x23\xaf\xbc\xf0\x0b\x74\xb9\x7f\xe2\xce\xb7\x14\xc6\x60\x8c\x25\xf0\x7d\x2e\x5d\xb5\x9a\xee\x25\x57\xf2\xef\x3f\x78\xec\xcf\xe2\xf3\x81\x15\x88\xfb\xee\xbb\x4f\xaa\xd5\x2a\x4f\x3c\xf1\xc4\x39\x47\x2b\x94\x52\x78\x9e\xc7\xc3\x0f\x3f\xcc\x8e\x1d\x3b\xd8\xbf\x7f\xff\xfb\xbb\xbd\x72\x21\x57\x09\x1c\x90\x91\xe7\xb4\xc2\x24\x0a\x5d\x08\x31\x05\x40\xa3\xd1\x2c\xf7\x3a\x20\x0a\x43\x82\xb2\xdf\x05\x30\xc6\x90\xe7\x39\x85\xb1\x9d\xc2\x60\x2d\x14\x52\x7a\x9c\x9d\x92\xd7\x2e\x59\xb6\x82\x3b\x6f\x5b\xcf\x4b\xcf\x3d\x41\x9e\xe5\x88\xb8\x7e\xd8\xed\x2b\x6b\xf7\x60\xb4\xcf\xfa\x3b\x37\xf1\xf6\xf0\x04\x5b\x9e\x7e\xfa\x03\x61\x73\x41\x12\xce\xc2\x85\x0b\x65\xe3\xc6\x8d\x1c\x3b\x76\x8c\xe7\x9e\x7b\xee\x9c\xec\x3c\x0c\x43\xd6\xae\x5d\x8b\xef\xfb\xec\xdc\xb9\x93\x46\xa3\x71\xde\x6b\x86\x9e\x93\xb0\x2a\xa1\x22\xf4\x15\xdd\xd5\xa4\x03\x90\x88\x70\xba\xde\xec\xd0\xa7\xc0\xd7\x24\x71\xe4\x84\x82\x2c\x77\x5e\x27\x8e\xc2\xb4\x15\xf0\x56\xb9\xdf\x92\x1a\xb7\x75\x90\x54\x2a\xdc\x74\xd3\x4d\x44\xba\xa0\x36\xfc\x47\xc4\x14\x1d\x3a\x63\xad\xf3\x3c\xe5\x05\x5c\x7f\xf3\x6d\x04\xdd\x0b\xf8\xd9\x93\x4f\x71\xfc\xf8\xf1\x0f\x8c\xcb\x87\xd2\xc0\x16\x2c\x58\x20\xb7\xdd\x76\x1b\x00\xa7\x4f\x9f\x66\x68\x68\x88\x93\x27\x4f\xe2\x79\x1e\x73\xe7\xce\x65\x60\x60\x80\xc5\x8b\x17\xb3\x7c\xf9\x72\x5e\x78\xe1\x05\x76\xee\xdc\x79\xde\xb0\xd6\x0a\x7a\x22\x45\x4f\xa2\xe8\xae\x84\x44\x41\x00\xca\xf5\xca\xf5\x66\x13\x6b\xdb\xca\xb2\xc2\xd3\x8e\xc3\x59\xdb\xf6\x30\xa1\x9e\x41\xb3\x14\x16\xda\x60\x27\x49\xc2\x4d\x37\xdd\xc4\x86\x0d\x1b\x18\x1a\x1a\x62\xfc\xe4\x51\x5a\xb5\x31\x26\x27\xc6\x10\x6b\xe8\xe9\x1b\x60\xf1\xe0\x32\xc2\xa4\x8b\x66\x6e\xf9\xf5\x6f\xb6\x8d\x9f\x38\x71\xa2\xff\x42\xb1\xf8\x7f\x4b\xfa\x51\x14\xb1\x64\xc9\x12\xe9\xe9\xe9\x41\x44\x18\x1b\x1b\x63\x74\x74\x54\xd5\xeb\x75\xfa\xfa\xfa\xee\xfa\xe2\x17\xbf\xf8\xcc\xe0\xe0\x20\x5b\xb6\x6c\x61\x78\x78\x98\x91\x91\x11\xde\x4f\xfd\x5d\xd8\xad\x98\x13\x6b\xa2\xc0\x27\x0c\x03\x04\x48\x5b\x19\x59\x61\xc8\x8d\x74\xf2\xa5\x15\xa1\x95\xc3\x58\xd3\xd2\xcc\xa7\x40\x53\x4a\x31\x77\xee\x5c\x06\x07\x07\xd9\xb8\x71\x23\x87\x0f\x1f\xe6\xc9\x27\x9f\xbc\x7b\x7c\x7c\xfc\xd9\x92\x6e\xc9\xc0\xc0\x00\x00\xa7\x4e\x9d\x62\x78\x78\x58\xbd\x5f\x8f\xfb\x89\x9a\x8d\xe9\xef\xef\xff\xe6\x03\x0f\x3c\xf0\xdd\xf1\xf1\x71\xb6\x6f\xdf\x4e\x51\x14\x64\x59\x46\xbd\x5e\x3f\xe3\xbc\x6a\x08\x4b\x7a\x7c\xba\xab\x49\x49\xa4\x15\x79\x61\x3a\xdd\x43\xad\x91\xe2\x2b\x8b\x15\x18\x6b\x08\xa3\x0d\x77\x4e\xa5\x52\x21\x8a\x22\x3c\xcf\xe3\x96\x5b\x6e\xa1\xa7\xa7\x87\x27\x9f\x7c\xf2\x5b\x63\x63\x63\xff\xfa\xa9\x9a\xce\x5a\xb9\x72\xa5\x6c\xda\xb4\x89\xc7\x1f\x7f\x9c\x89\x89\x09\xe2\x38\xa6\x28\x0a\x5a\xad\x56\x27\x1f\x2e\x9d\x5b\xa1\x1a\x58\xe2\x30\xc0\x5a\x4b\xad\x99\x11\x07\x1e\x51\x14\x22\x68\x6a\xb5\x1a\x02\x8c\x37\x2c\x93\x26\xc6\xf3\x3c\x5a\xad\x16\x7d\x7d\x7d\x3c\xf2\xc8\x23\x6c\xd9\xb2\x85\x77\xde\x79\xe7\x2f\x76\x5f\x7f\xf1\x99\xba\x30\x0c\xf9\xc6\x37\xbe\x21\xcf\x3e\xfb\x2c\xfb\xf6\xed\xc3\xf3\xbc\x4e\x45\xf5\x3c\xcd\xdc\xaa\xc7\x40\x85\x52\xb5\xd6\x25\xff\xd4\x6e\x5b\xd4\xd3\xd4\x1b\x4d\xac\x31\xd4\x0b\xcd\xa1\x71\x83\xb5\x96\xd5\xab\x57\x73\xeb\xad\xb7\xf2\xfd\xef\x7f\xff\x2f\x32\x91\x35\xa3\x00\xb6\xed\xd1\x47\x1f\x95\xd7\x5f\x7f\x9d\xdd\xbb\x77\x97\x45\xc1\xe2\x79\x1e\x91\x07\x73\x2b\xe2\xe4\x7c\xdd\xae\xc6\x2e\xf7\x05\x81\x0f\x62\xcb\x6d\x4d\xcd\xbe\x11\xc3\x9a\xab\xaf\x65\xf5\xea\xd5\xfc\xf0\x87\x3f\xfc\xf4\x0f\x58\x9e\x6d\x0f\x3d\xf4\x90\x1c\x3f\x7e\x9c\xe7\x9f\x7f\x7e\x6a\x54\xc2\xf3\x10\x6b\xa8\x86\x8e\x27\x7a\xda\x51\x94\x56\x21\x54\xa2\x80\xbe\xd8\x76\x3a\x8c\x95\x37\xde\x8e\x97\xf4\xb2\x79\xf3\xe6\x19\xbb\x0f\x3d\x93\x00\x6e\xde\xbc\x59\x2d\x5b\xb6\xec\x8c\x63\x4e\x0d\x71\xf2\xd7\x89\xd3\xc2\x89\xd3\xc2\xc9\xba\xd0\xcc\x21\xf1\xcc\x34\xe5\x11\x96\x2f\x5d\x32\xa3\xe0\xcd\x38\x80\x97\x5f\x7e\xb9\xec\xdd\xbb\xf7\xbc\x12\x98\xb1\xae\xf5\x1b\xec\xd1\x6e\xa7\x2e\x08\xd0\xca\xed\xd0\x1f\x1d\x7a\x8b\x55\xab\x56\xc9\x45\x0b\xe0\x35\xd7\x5c\xc3\xab\xaf\xbe\x7a\xc6\x31\x4f\x41\xe0\xb9\x9d\xbd\xfe\x44\xb1\xb4\x57\xb3\xa0\xcb\x75\x29\x71\x1c\x11\x86\x21\x41\x18\x02\x8a\x37\x76\xef\x62\xdd\xda\xeb\x67\xf2\x16\x3e\xfa\xf1\xb6\x0b\xb5\xb6\x0a\x13\xf9\x94\xd2\x94\x13\x18\xa6\xcb\xf9\x0a\xe5\x76\xd3\xca\x8a\xed\x79\x4e\xab\xb3\xd6\xd0\x1d\xcf\xa8\x0f\xcc\x9c\x07\xf6\xf4\xf4\x30\x31\x31\xd1\xa9\x64\xd5\x50\x11\xe8\x52\xde\x6a\x0b\xa8\xb8\x57\xd4\xb4\x8a\x5c\xd6\x3d\xad\x3d\x10\x30\xcd\x49\xba\xbb\xbb\x2f\x3e\x00\xd7\xac\x59\x23\xaf\xbd\xf6\x9a\xf3\x28\xdd\x1e\x79\xeb\x88\x8c\x9d\x69\xa1\x76\xdb\x67\xda\x9b\x54\xe5\xef\xaa\xdc\xba\xdb\xb7\xf7\x55\xae\xbd\xf6\x1a\xb9\xe8\x00\x9c\x37\x6f\x1e\xc7\x8f\x1f\xef\x88\x09\x5a\xbd\xb7\x84\xc8\x94\x6a\xeb\x36\xd4\xcf\x92\xd1\x44\x60\xf4\xe4\x71\x16\x2d\x98\x77\xf1\x79\xe0\x74\x41\x41\xab\xb3\x09\xa9\x2a\x43\x55\x75\x7e\x16\x20\x2b\x75\x3c\x91\x32\x77\x96\x5b\x01\xb1\xc7\xc5\x07\xe0\x19\x95\x57\x9f\x4d\xe9\xa5\xe3\x62\xd3\xc7\x3a\xac\xb5\xa4\x59\x86\xb5\xd6\x01\x58\xbe\x17\xcd\x60\x29\xf4\x3f\xa9\x1e\x58\x26\xba\xf7\x1c\x2b\xca\x50\x56\x9d\x3c\xe8\x68\xcf\x45\xe5\x81\xfd\xfd\xfd\xdf\x1c\x1d\x1d\x9d\x06\xa0\x3a\x07\x85\x6e\x67\x41\x39\xa3\x78\x70\x8e\x63\xf5\xc9\x71\x7a\x7b\x7b\x2f\xbb\x68\x00\x5c\xbe\x7c\xf9\x77\x0f\x1c\x38\xd0\xf1\xab\x36\xd7\x3b\x17\x88\x6d\x6f\x9d\x3e\x7d\xd5\xa9\xd0\xe5\x7b\xc3\x87\x0e\xb0\x7c\xf9\xf2\x77\x2e\x1a\x00\x17\x2c\x58\xc0\xd1\xa3\x47\xdf\x07\xae\x29\x58\x95\x94\xaf\x4a\x9d\x01\xb5\x2b\x1e\x53\xef\x9d\x38\x7e\x94\x45\x8b\x16\x5e\x3c\x21\x7c\xf6\x3c\x8d\xbc\xcf\x77\x37\x41\x25\x67\x41\x7c\x66\x61\x11\x01\xb1\x96\x68\x86\x12\xe1\x8c\x57\x61\xc1\x4d\x6b\xd9\x69\x58\xc9\x74\x4f\x2c\xa9\xca\x54\x99\x29\xa9\x8d\x4c\x75\x25\x22\xe0\x31\x33\x5c\x7a\x46\xaa\xf0\xd9\x84\x38\x35\x10\x18\x50\xe5\x3e\x48\x7b\x17\xc4\x9f\xfe\x2f\x0c\x67\x55\xdb\x8e\x17\x2b\xd5\x99\x7a\xb9\x68\x01\xcc\x0c\xd4\x33\xc1\xa2\xf0\xb5\x62\xa4\xe5\xa6\x49\xa7\xef\x0f\x2b\xa5\x98\x9b\x18\xba\x42\x99\x76\x8c\xce\xec\x34\x17\x13\x80\x5a\xbf\x37\x73\xa4\x06\x24\x13\x7a\x62\x28\x8a\x9c\xc2\xc8\x7b\xf2\x66\x16\xba\xc9\xaa\x73\x29\xa8\x6a\x86\xb2\xd1\x8c\x7c\x6a\xb5\x5a\x3d\xe7\xf1\xcc\x40\x23\xb3\x5c\xd2\xa3\xa9\x84\xaa\xfc\x37\xd8\x72\xf8\x47\x0b\x81\x76\xd3\x55\x46\xa4\x33\x69\x65\xca\xf9\x17\x3f\xaa\xcc\x08\x80\x33\x22\x87\xaf\x5d\xbb\x56\xa2\x28\x62\xfb\xf6\xed\xe7\xa8\xd0\x6e\x6f\x78\xde\x9c\x00\x8d\x22\xcb\x73\x9a\x99\xe1\x54\xcb\xcd\x56\x07\xde\xb4\x81\xf5\xb2\xc0\xac\x5b\x7f\x2b\xfb\x8f\xd5\xd8\xb5\x6b\x97\xba\x28\x00\x04\xb8\xf7\xde\x7b\x65\xd1\xa2\x45\x6c\xdb\xb6\x8d\x36\xa9\x3e\x23\xb7\x68\x08\x7d\x57\x6d\x33\xe3\xc0\x9b\xde\xfa\x69\x05\x2b\x56\xac\x60\xc3\x2d\xb7\x70\x78\xf8\x28\x5b\xb7\x6e\xbd\xf8\x76\xe5\x94\x52\xac\x5d\xbb\x56\x06\x07\x07\x3b\x02\x81\x88\x50\xab\xd5\x38\x75\xea\x54\x67\x30\xa9\x52\xa9\xd0\xd3\xd3\x43\x77\x77\x37\x5a\xeb\x72\x46\x50\xf3\xee\xbb\xef\xf2\xf2\xcb\x2f\x7f\xe8\x7f\x14\xfc\xab\x07\xf0\xfd\xac\x52\xa9\xd0\xdd\xdd\x2d\x49\x92\x20\x22\xa4\x69\x4a\xad\x56\x53\x67\x8f\x82\xcc\xda\xac\xcd\xda\xac\xcd\xda\xac\xcd\xda\xac\xcd\xda\xac\xcd\x94\xfd\x1f\x36\xdc\x79\x3b\x76\xfb\x56\x3b\x00\x00\x00\x00\x49\x45\x4e\x44\xae\x42\x60\x82\x01\x00\x00\xff\xff\x79\x18\x23\x59\x87\x13\x00\x00")

func static_img_smcquay_png_bytes() ([]byte, error) {
	return bindata_read(
		_static_img_smcquay_png,
		"static/img/smcquay.png",
	)
}

func static_img_smcquay_png() (*asset, error) {
	bytes, err := static_img_smcquay_png_bytes()
	if err != nil {
		return nil, err
	}

	info := bindata_file_info{name: "static/img/smcquay.png", size: 4999, mode: os.FileMode(420), modTime: time.Unix(1423545222, 0)}
	a := &asset{bytes: bytes, info:  info}
	return a, nil
}

var _static_index_html = []byte("\x1f\x8b\x08\x00\x00\x09\x6e\x88\x00\xff\x9c\x54\x5b\x4f\xdb\x30\x14\x7e\xdf\xaf\xf0\xf2\x92\x64\x72\x9d\x75\x42\xbb\x35\x41\x82\x81\xa6\x3d\x00\x9b\xc6\x1e\xa6\xaa\x0f\xc6\x39\x75\x0c\x89\x1d\xec\x53\xb2\x88\xf2\xdf\xe7\x5c\x80\xd2\xee\xa2\xad\x0f\xcd\xb9\xe5\x9c\xef\xfb\x4e\xec\xf4\xf9\xd1\xd9\x87\xf3\xef\x9f\x8f\x49\x81\x55\xb9\xff\x2c\x1d\x1e\xc4\xff\xd2\x02\x78\x3e\x98\xbd\x5b\x01\x72\x22\x8c\x46\xd0\x98\x05\x8d\xca\xb1\xc8\x72\xb8\x51\x02\x26\xbd\x43\x89\xd2\x0a\x15\x2f\x27\x4e\xf0\x12\xb2\x69\x40\x34\xaf\x20\x0b\x6e\x14\x34\xb5\xb1\x18\x6c\x34\x43\x85\x25\xec\xbb\x4a\x5c\xaf\x78\x9b\x26\x83\xfb\x98\x2e\x95\xbe\x22\x16\xca\x2c\x70\xd8\x96\xe0\x0a\x00\x0c\x08\xb6\xb5\x6f\x87\xf0\x03\x13\xe1\x5c\x40\x0a\x0b\xcb\x2c\xe8\xec\xc4\x55\xac\x0b\x8d\xc8\x93\x47\xe8\xe9\x85\xc9\xdb\x8d\xce\xb9\xba\x21\x2a\xcf\x82\x91\xc8\x06\xa6\x27\xe9\x1e\xd0\x56\xb2\x2f\xe0\xe3\xd4\x02\xb1\x76\xef\x93\xc4\x81\x60\x03\x0b\x56\xf9\x17\x1e\x18\xf1\xad\xc6\x89\xef\xfc\x9b\x59\xb5\x12\xff\x31\x29\x55\x95\x24\xce\x0a\x2f\x80\xb7\x92\x71\x30\xab\xb5\xf4\xb9\x7f\x19\xaf\xf4\xd2\xfc\x6a\x7e\xbd\x1b\x3b\x69\xfb\x95\x12\xe5\x9e\xc2\xeb\xd0\x21\xd4\x05\xe8\x4d\x84\x5f\x87\x10\x39\x11\x5f\x46\x49\x28\xf9\x3b\x4d\x6c\x14\x22\x58\x26\x4c\x75\x4f\xea\x89\xac\xc4\x68\x82\x85\xc7\xe0\xf7\x67\x35\x20\xdb\x69\xf9\x89\xb8\x1a\xf8\xd5\x6e\x6b\x69\x4a\xae\x25\x33\xd6\x4b\x24\x8d\xc7\x66\x77\x84\x1a\xc4\xaa\xff\xa8\xde\xb6\xeb\x84\x55\x35\xee\x93\x68\xb9\xd2\x02\x95\xd1\x91\xa2\x8e\x1a\x2a\xa9\xa5\x9c\x56\xf1\xad\x9a\x87\x1f\x8d\x91\x25\x1c\x68\x5e\xb6\xa8\x84\x3b\xbb\xb8\x04\x81\xe1\x22\xb3\x33\x35\xb7\x8b\xac\xfb\x5b\xaf\x1f\xde\x8f\x6f\x49\xd4\x85\xd8\x75\x36\x3c\xd6\xeb\xf9\x22\x66\xf5\xca\x15\x11\xb7\x72\x55\xf9\x2f\xd7\xc5\x77\xb4\x4f\x96\xd9\xf4\x85\x86\x86\x1c\x71\x84\x28\x9e\xf1\xcc\x31\x61\xc1\x3b\xc7\x25\x74\x85\x91\x89\x29\xa9\x7c\x54\x02\x8e\x21\x77\xd8\x9e\x73\x79\xea\x57\xe9\x93\xf3\x97\x8b\x19\x67\xdc\xb5\x5a\x64\x53\x6f\x75\xdf\x94\x9c\x55\xac\xe6\xd6\x97\x9e\x9a\x1c\x98\xd2\x0e\x2c\x1e\xc2\xd2\x58\x88\x3a\x4a\xe4\x2e\x8e\x1a\xa5\x73\xd3\xd0\xdc\x88\x1e\x0f\x0d\x07\x1d\x42\x1a\x26\x49\xd3\x34\x4c\xf6\x94\x27\xfc\x9e\x73\xbf\xd1\x47\xef\xd2\xf9\x4a\xc9\xc3\x78\x46\x24\x8f\xc2\x01\x72\x48\x49\xf8\xed\x60\xf2\xea\xed\xeb\x77\xd3\xbd\x37\x93\xbd\xce\xe7\x2b\x34\xf7\x55\x0e\x74\xde\xc5\x6a\x2e\xa1\xbb\x56\xba\x78\x9a\x8c\x0b\x18\xcf\xfe\x70\xe0\xfd\x1d\xd0\xdf\x64\x3f\x03\x00\x00\xff\xff\x60\xa5\x9a\x15\xe1\x04\x00\x00")

func static_index_html_bytes() ([]byte, error) {
	return bindata_read(
		_static_index_html,
		"static/index.html",
	)
}

func static_index_html() (*asset, error) {
	bytes, err := static_index_html_bytes()
	if err != nil {
		return nil, err
	}

	info := bindata_file_info{name: "static/index.html", size: 1249, mode: os.FileMode(420), modTime: time.Unix(1423548212, 0)}
	a := &asset{bytes: bytes, info:  info}
	return a, nil
}

// Asset loads and returns the asset for the given name.
// It returns an error if the asset could not be found or
// could not be loaded.
func Asset(name string) ([]byte, error) {
	cannonicalName := strings.Replace(name, "\\", "/", -1)
	if f, ok := _bindata[cannonicalName]; ok {
		a, err := f()
		if err != nil {
			return nil, fmt.Errorf("Asset %s can't read by error: %v", name, err)
		}
		return a.bytes, nil
	}
	return nil, fmt.Errorf("Asset %s not found", name)
}

// AssetInfo loads and returns the asset info for the given name.
// It returns an error if the asset could not be found or
// could not be loaded.
func AssetInfo(name string) (os.FileInfo, error) {
	cannonicalName := strings.Replace(name, "\\", "/", -1)
	if f, ok := _bindata[cannonicalName]; ok {
		a, err := f()
		if err != nil {
			return nil, fmt.Errorf("AssetInfo %s can't read by error: %v", name, err)
		}
		return a.info, nil
	}
	return nil, fmt.Errorf("AssetInfo %s not found", name)
}

// AssetNames returns the names of the assets.
func AssetNames() []string {
	names := make([]string, 0, len(_bindata))
	for name := range _bindata {
		names = append(names, name)
	}
	return names
}

// _bindata is a table, holding each asset generator, mapped to its name.
var _bindata = map[string]func() (*asset, error){
	"static/css/sm.css": static_css_sm_css,
	"static/favicon.ico": static_favicon_ico,
	"static/img/smcquay.png": static_img_smcquay_png,
	"static/index.html": static_index_html,
}

// AssetDir returns the file names below a certain
// directory embedded in the file by go-bindata.
// For example if you run go-bindata on data/... and data contains the
// following hierarchy:
//     data/
//       foo.txt
//       img/
//         a.png
//         b.png
// then AssetDir("data") would return []string{"foo.txt", "img"}
// AssetDir("data/img") would return []string{"a.png", "b.png"}
// AssetDir("foo.txt") and AssetDir("notexist") would return an error
// AssetDir("") will return []string{"data"}.
func AssetDir(name string) ([]string, error) {
	node := _bintree
	if len(name) != 0 {
		cannonicalName := strings.Replace(name, "\\", "/", -1)
		pathList := strings.Split(cannonicalName, "/")
		for _, p := range pathList {
			node = node.Children[p]
			if node == nil {
				return nil, fmt.Errorf("Asset %s not found", name)
			}
		}
	}
	if node.Func != nil {
		return nil, fmt.Errorf("Asset %s not found", name)
	}
	rv := make([]string, 0, len(node.Children))
	for name := range node.Children {
		rv = append(rv, name)
	}
	return rv, nil
}

type _bintree_t struct {
	Func func() (*asset, error)
	Children map[string]*_bintree_t
}
var _bintree = &_bintree_t{nil, map[string]*_bintree_t{
	"static": &_bintree_t{nil, map[string]*_bintree_t{
		"css": &_bintree_t{nil, map[string]*_bintree_t{
			"sm.css": &_bintree_t{static_css_sm_css, map[string]*_bintree_t{
			}},
		}},
		"favicon.ico": &_bintree_t{static_favicon_ico, map[string]*_bintree_t{
		}},
		"img": &_bintree_t{nil, map[string]*_bintree_t{
			"smcquay.png": &_bintree_t{static_img_smcquay_png, map[string]*_bintree_t{
			}},
		}},
		"index.html": &_bintree_t{static_index_html, map[string]*_bintree_t{
		}},
	}},
}}

// Restore an asset under the given directory
func RestoreAsset(dir, name string) error {
        data, err := Asset(name)
        if err != nil {
                return err
        }
        info, err := AssetInfo(name)
        if err != nil {
                return err
        }
        err = os.MkdirAll(_filePath(dir, path.Dir(name)), os.FileMode(0755))
        if err != nil {
                return err
        }
        err = ioutil.WriteFile(_filePath(dir, name), data, info.Mode())
        if err != nil {
                return err
        }
        err = os.Chtimes(_filePath(dir, name), info.ModTime(), info.ModTime())
        if err != nil {
                return err
        }
        return nil
}

// Restore assets under the given directory recursively
func RestoreAssets(dir, name string) error {
        children, err := AssetDir(name)
        if err != nil { // File
                return RestoreAsset(dir, name)
        } else { // Dir
                for _, child := range children {
                        err = RestoreAssets(dir, path.Join(name, child))
                        if err != nil {
                                return err
                        }
                }
        }
        return nil
}

func _filePath(dir, name string) string {
        cannonicalName := strings.Replace(name, "\\", "/", -1)
        return filepath.Join(append([]string{dir}, strings.Split(cannonicalName, "/")...)...)
}

